<?php

namespace Assetdocs\Customer\Providers;

use Illuminate\Support\ServiceProvider;

class CustomerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'customer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'customer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('assetdocs.customer', function ($app) {
            return $this->app->make('Assetdocs\Customer\Customer');
        });

                // Bind Customer to repository
        $this->app->bind(
            'Assetdocs\Customer\Interfaces\CustomerRepositoryInterface',
            \Assetdocs\Customer\Repositories\Eloquent\CustomerRepository::class
        );

        $this->app->register(\Assetdocs\Customer\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Assetdocs\Customer\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['assetdocs.customer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('assetdocs/customer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/customer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/customer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
